@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2009 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 1998-2011 Proofpoint, Inc. and its suppliers.
  *	All rights reserved.
  * Copyright (c) 1983, 1995-1997 Eric P. Allman.  All rights reserved.
  * Copyright (c) 1988, 1993
@@ -10,7 +10,7 @@
  * the sendmail distribution.
  *
  *
- *	$Id: conf.h,v 1.139 2009/06/16 23:41:32 ca Exp $
+ *	$Id: conf.h,v 1.147 2013/11/22 20:51:31 ca Exp $
  */
 
 /*
@@ -381,6 +381,12 @@ typedef int		pid_t;
 #   ifndef __svr4__
 #    define __svr4__		/* use all System V Release 4 defines below */
 #   endif /* ! __svr4__ */
+#   if SOLARIS >= 21100
+#    include <paths.h>
+#   endif /* SOLARIS >= 21100 */
+#   ifndef _PATH_VARRUN
+#    define _PATH_VARRUN	"/var/run/"
+#   endif /* _PATH_VARRUN */
 #   define GIDSET_T	gid_t
 #   define USE_SA_SIGACTION	1	/* use sa_sigaction field */
 #   define BROKEN_PTHREAD_SLEEP	1	/* sleep after pthread_create() fails */
@@ -443,7 +449,7 @@ typedef int		pid_t;
 #   endif /* SOLARIS >= 20700 || (SOLARIS < 10000 && SOLARIS >= 207) */
 #   if SOLARIS >= 20800 || (SOLARIS < 10000 && SOLARIS >= 208)
 #    undef _PATH_SENDMAILPID	/* tmpfs /var/run added in 2.8 */
-#    define _PATH_SENDMAILPID	"/var/run/sendmail.pid"
+#    define _PATH_SENDMAILPID	_PATH_VARRUN "sendmail.pid"
 #    ifndef SMRSH_CMDDIR
 #     define SMRSH_CMDDIR	"/var/adm/sm.bin"
 #    endif /* ! SMRSH_CMDDIR */
@@ -461,6 +467,8 @@ typedef int		pid_t;
 #   if SOLARIS >= 21100 || (SOLARIS < 10000 && SOLARIS >= 211)
 #    define GETLDAPALIASBYNAME_VERSION 2	/* changed in S11 */
 #    define HAVE_NANOSLEEP	1	/* moved from librt to libc in S11 */
+#    define SOCKADDR_LEN_T	socklen_t	/* arg#3 to accept, getsockname */
+#    define SOCKOPT_LEN_T	socklen_t	/* arg#5 to getsockopt */
 #   endif /* SOLARIS >= 21100 || (SOLARIS < 10000 && SOLARIS >= 211) */
 #   ifndef HASGETUSERSHELL
 #    define HASGETUSERSHELL 0	/* getusershell(3) causes core dumps pre-2.7 */
@@ -1014,6 +1022,9 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #    if __FreeBSD_version >= 222000	/* 2.2.2-release and later */
 #     define HASSETUSERCONTEXT	1	/* BSDI-style login classes */
 #    endif /* __FreeBSD_version >= 222000 */
+#    if __FreeBSD_version >= 300000	/* 3.0.0-release and later */
+#     define HAVE_NANOSLEEP	1	/* has nanosleep(2) */
+#    endif /* __FreeBSD_version >= 300000 */
 #    if __FreeBSD_version >= 330000	/* 3.3.0-release and later */
 #     ifndef SMRSH_CMDDIR
 #      define SMRSH_CMDDIR	"/usr/libexec/sm.bin"
@@ -1055,6 +1066,9 @@ extern unsigned int sleepX __P((unsigned int seconds));
 #   if OpenBSD >= 200505
 #    undef NETISO	/* iso.h removed in 3.7 */
 #   endif /* OpenBSD >= 200505 */
+#   if OpenBSD >= 200800
+#    define HAVE_NANOSLEEP	1	/* has nanosleep(2) */
+#   endif /* OpenBSD >= 200800 */
 #  endif /* defined(__OpenBSD__) */
 # endif /* defined(__DragonFly__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) */
 
@@ -1518,6 +1532,8 @@ extern void		*malloc();
 #   if defined(__GLIBC__) && defined(__GLIBC_MINOR__)
 #    define GLIBC_VERSION ((__GLIBC__ << 8) + __GLIBC_MINOR__)
 #    if (GLIBC_VERSION >= 0x201)
+#     define SOCKADDR_LEN_T     socklen_t
+#     define SOCKOPT_LEN_T      socklen_t
 #     undef IPPROTO_ICMPV6	/* linux #defines, glibc enums */
 #    else /* (GLIBC_VERSION >= 0x201) */
 #     include <linux/in6.h>	/* IPv6 support */
@@ -2808,7 +2824,7 @@ struct utsname
 
 # if _FFR_LINUX_MHNL && defined(__linux__) && MAXHOSTNAMELEN < 255
    /*
-   **  override Linux wierdness: a FQHN can be 255 chars long
+   **  override Linux weirdness: a FQHN can be 255 chars long
    **  SUSv3 requires HOST_NAME_MAX ("Maximum length of a host
    **  name (not including the terminating null) as returned from the
    **  gethostname() function.") to be at least 255.  c.f.:
@@ -2949,6 +2965,11 @@ typedef void		(*sigfunc_t) __P((int));
 #  define SM_INT32	int32_t
 # endif /* ! SM_INT32 */
 
+/* XXX  16 bit type */
+# ifndef SM_UINT16
+#  define SM_UINT16	uint16_t
+# endif /* ! SM_UINT16 */
+
 /*
 **  SVr4 and similar systems use different routines for setjmp/longjmp
 **  with signal support
@@ -3031,4 +3052,6 @@ struct sm_align
 # endif /* ! SM_ALIGN_SIZE */
 # define SM_ALIGN_BITS (SM_ALIGN_SIZE - 1)
 
+char *sm_inet6_ntop __P((const void *, char *, size_t));
+
 #endif /* ! SM_CONF_H */
