@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2001, 2004 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 2000-2001, 2004 Proofpoint, Inc. and its suppliers.
  *      All rights reserved.
  * Copyright (c) 1990
  *	The Regents of the University of California.  All rights reserved.
@@ -13,7 +13,7 @@
  */
 
 #include <sm/gen.h>
-SM_IDSTR(id, "@(#)$Id: vfprintf.c,v 1.53 2004/08/03 20:54:49 ca Exp $")
+SM_IDSTR(id, "@(#)$Id: vfprintf.c,v 1.55 2013/11/22 20:51:44 ca Exp $")
 
 /*
 **  Overall:
@@ -535,9 +535,19 @@ reswitch:	switch (ch)
 				if (prec > 120)
 					prec = 120;
 				if (prec >= 0)
+#if HASSNPRINTF
+					snprintf(out, sizeof(out), fmt, width,
+						prec, val);
+#else /* HASSNPRINTF */
 					sprintf(out, fmt, width, prec, val);
+#endif /* HASSNPRINTF */
 				else
+#if HASSNPRINTF
+					snprintf(out, sizeof(out), fmt, width,
+						val);
+#else /* HASSNPRINTF */
 					sprintf(out, fmt, width, val);
+#endif /* HASSNPRINTF */
 				len = strlen(out);
 				PRINT(out, len);
 				FLUSH();
