@@ -1,3 +1,13 @@
+/*
+ * Copyright (c) 1999 Proofpoint, Inc. and its suppliers.
+ *	All rights reserved.
+ *
+ * By using this file, you agree to the terms and conditions set
+ * forth in the LICENSE file which can be found at the top level of
+ * the sendmail distribution.
+ *
+ */
+
 /*
 **  The following test program tries the pathconf(2) routine.  It should
 **  be run in a non-NFS-mounted directory (e.g., /tmp) and on remote (NFS)
@@ -16,7 +26,7 @@
 #include <sysexits.h>
 
 #ifndef lint
-static char id[] = "@(#)$Id: t_pathconf.c,v 8.5 1999/08/28 00:25:28 gshapiro Exp $";
+static char id[] = "@(#)$Id: t_pathconf.c,v 8.7 2013/11/22 20:52:01 ca Exp $";
 #endif /* ! lint */
 
 int
